@@ -111,7 +111,8 @@ srv_snapshot_manager_panel <- function(id, slices_global) {
         )
       )
     })
-    srv_snapshot_manager("module", slices_global = slices_global)
+    snapshot_history <- srv_snapshot_manager("module", slices_global = slices_global)
+    snapshot_history
   })
 }
 
@@ -183,6 +184,12 @@ srv_snapshot_manager <- function(id, slices_global) {
         modalDialog(
           easyClose = TRUE,
           textInput(ns("snapshot_name"), "Name the snapshot", width = "100%", placeholder = "Meaningful, unique name"),
+          tags$script(
+            shiny::HTML(
+              sprintf("shinyjs.autoFocusModal('%s');", ns("snapshot_name")),
+              sprintf("shinyjs.enterToSubmit('%s', '%s');", ns("snapshot_name"), ns("snapshot_name_accept"))
+            )
+          ),
           footer = shiny::div(
             shiny::tags$button(
               type = "button",
