@@ -9,15 +9,7 @@
 #' @keywords internal
 "_PACKAGE"
 
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
-# Fix R CMD check notes
 #' @import shiny teal.data teal.slice
 #' @importFrom stats setNames
+#' @export
 NULL
-
-# Fix R CMD check notes
-#' @importFrom lifecycle badge
-lifecycle::badge
