@@ -315,8 +315,9 @@ validate_app_title_tag <- function(shiny_tag) {
 #' @return A `shiny.tag` containing the element that adds the title and logo to the `shiny` app.
 #' @export
 build_app_title <- function(
-    title = "teal app",
-    favicon = "https://raw.githubusercontent.com/insightsengineering/hex-stickers/main/PNG/nest.png") {
+  title = "teal app",
+  favicon = "https://raw.githubusercontent.com/insightsengineering/hex-stickers/main/PNG/nest.png"
+) {
   lifecycle::deprecate_soft(
     when = "0.16.0",
     what = "build_app_title()",
