@@ -27,8 +27,10 @@ testthat::test_that("e2e: module with decorator UI and output is modified intera
   )
 
   app <- TealAppDriver$new(
-    data = teal.data::teal_data(x = "Text Input"),
-    modules = example_module(label = "Example Module", decorators = list(interactive_decorator))
+    init(
+      data = teal.data::teal_data(x = "Text Input"),
+      modules = example_module(label = "Example Module", decorators = list(interactive_decorator))
+    )
   )
 
   app$navigate_teal_tab("Example Module")
@@ -39,11 +41,11 @@ testthat::test_that("e2e: module with decorator UI and output is modified intera
   )
 
   testthat::expect_true(
-    app$is_visible(sprintf("#%s-%s", app$active_module_ns(), input_id))
+    app$is_visible(app$namespaces(TRUE)$module(input_id))
   )
 
   testthat::expect_identical(
-    app$active_module_element_text(sprintf("%s-label", input_id)),
+    app$get_text(app$namespaces(TRUE)$module(sprintf("%s-label", input_id))),
     "Append text"
   )
 
@@ -54,16 +56,13 @@ testthat::test_that("e2e: module with decorator UI and output is modified intera
 
   testthat::expect_identical(
     app$get_active_module_output("text"),
-    paste0('[1] \"', "Text Input", "random text", '\"'),
     "[1] \"Text Inputrandom text\""
   )
 
   app$set_active_module_input(input_id, "new text")
-
   testthat::expect_identical(
     app$get_active_module_output("text"),
-    paste0('[1] \"', "Text Input", "new text", '\"'),
-    "[1] \"Text Inputrandom text\""
+    "[1] \"Text Inputnew text\""
   )
 
   app$stop()
@@ -85,8 +84,10 @@ testthat::test_that("e2e: module with decorator, where server fails,  shows shin
     }
   )
   app <- TealAppDriver$new(
-    data = teal.data::teal_data(iris = iris),
-    modules = example_module(label = "Example Module", decorators = list(failing_decorator))
+    init(
+      data = teal.data::teal_data(iris = iris),
+      modules = example_module(label = "Example Module", decorators = list(failing_decorator))
+    )
   )
 
   app$navigate_teal_tab("Example Module")
@@ -96,12 +97,12 @@ testthat::test_that("e2e: module with decorator, where server fails,  shows shin
     c("decorate", "transform_1", "silent_error", "message")
   )
 
-  testthat::expect_true(app$is_visible(sprintf("#%s-%s", app$active_module_ns(), input_id)))
+  testthat::expect_true(app$is_visible(app$namespaces(TRUE)$module(input_id)))
 
   app$expect_validation_error()
 
   testthat::expect_identical(
-    strsplit(app$active_module_element_text(input_id), "\n")[[1]],
+    strsplit(app$get_text(app$namespaces(TRUE)$module(input_id)), "\n")[[1]],
     c(
       "Shiny error when executing the `data` module.",
       "This is error",
